@@ -148,12 +148,7 @@ class Resource:
         except Exception as e:  # pylint: disable=broad-except
             LOG.exception("Invalid request")
             raise InvalidRequest(f"{e} ({type(e).__name__})") from e
-        return (
-            (caller_sess, provider_sess),
-            action,
-            callback_context,
-            event,
-        )
+        return ((caller_sess, provider_sess), action, callback_context, event)
 
     def _cast_resource_request(
         self, request: HandlerRequest
@@ -163,7 +158,12 @@ class Resource:
                 clientRequestToken=request.bearerToken,
                 desiredResourceState=request.requestData.resourceProperties,
                 previousResourceState=request.requestData.previousResourceProperties,
+                desiredResourceTags=request.requestData.stackTags,
+                previousResourceTags=request.requestData.previousStackTags,
+                systemTags=request.requestData.systemTags,
+                awsAccountId=request.awsAccountId,
                 logicalResourceIdentifier=request.requestData.logicalResourceId,
+                region=request.region,
             ).to_modelled(self._model_cls)
         except Exception as e:  # pylint: disable=broad-except
             LOG.exception("Invalid request")
@@ -186,13 +186,14 @@ class Resource:
         try:
             sessions, action, callback, event = self._parse_request(event_data)
             caller_sess, provider_sess = sessions
-            ProviderLogHandler.setup(event, provider_sess)
-            logs_setup = True
 
             request = self._cast_resource_request(event)
 
-            metrics = MetricsPublisherProxy(event.awsAccountId, event.resourceType)
-            metrics.add_metrics_publisher(provider_sess)
+            metrics = MetricsPublisherProxy()
+            if event.requestData.providerLogGroupName and provider_sess:
+                ProviderLogHandler.setup(event, provider_sess)
+                logs_setup = True
+                metrics.add_metrics_publisher(provider_sess, event.resourceType)
 
             metrics.publish_invocation_metric(datetime.utcnow(), action)
             start_time = datetime.utcnow()
